==> haskell-conduit-parse-0.2.1.0-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit-parse
version:              0.2.1.0
visibility:           public
id:                   conduit-parse-0.2.1.0-3awqCrKduUtEWKNpEZY772
key:                  conduit-parse-0.2.1.0-3awqCrKduUtEWKNpEZY772
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  2eba556ee30d61823065a4460b841ac4
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/conduit-parse-0.2.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/conduit-parse-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/conduit-parse-0.2.1.0
hs-libraries:         HSconduit-parse-0.2.1.0-3awqCrKduUtEWKNpEZY772
depends:
    base-4.15.0.0 conduit-1.3.4.1-HliYTK9Hh7qL3jfQevLfcQ
    dlist-1.0-A8ZakkvDKerBegx9VfkpzR mtl-2.2.2
    parsers-0.12.10-3mggUgJGfYI4aBYreJgkBX
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj
    safe-exceptions-0.1.7.2-Bm7d3OZ9EQbJpiXD7szDLr text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-parse-0.2.1.0-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit-parse
version:              0.2.1.0
visibility:           public
id:                   conduit-parse-0.2.1.0-2CDC9vHxnWa8k8u9bHLDAd
key:                  conduit-parse-0.2.1.0-2CDC9vHxnWa8k8u9bHLDAd
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  70b690c592c095ff3d81c7df59bf2fbe
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/conduit-parse-0.2.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/conduit-parse-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/conduit-parse-0.2.1.0
hs-libraries:         HSconduit-parse-0.2.1.0-2CDC9vHxnWa8k8u9bHLDAd
depends:
    base-4.15.0.0 conduit-1.3.4.1-7ubKvw2j8afFY9XAmrTviB
    dlist-1.0-A8ZakkvDKerBegx9VfkpzR mtl-2.2.2
    parsers-0.12.10-BwJmNchfy7lKfw4l3fk6w1
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj
    safe-exceptions-0.1.7.2-Bm7d3OZ9EQbJpiXD7szDLr text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
